/*= z1_slaveioi.h ==============================================================
 *
 * Copyright (C) 2005 Nordic Semiconductor
 *
 * This file is distributed in the hope that it will be useful, but WITHOUT
 * WARRANTY OF ANY KIND.
 *
 * Author(s): Borge Strand
 *
 * Description:
 *
 *    Declarations used by primitive nRF24Z1 register access.
 *
 * Compiler: Tested with WinAVR, avr-gcc (GCC) 3.4.3
 *
 * Revision: 2.0 
 *
 *==============================================================================
 */
 

// Only include this file once
#ifndef Z1SLAVEIO_H
#define Z1SLAVEIO_H


// Local includes
#include "mcu.h"
#include "hpref_defines.h"
#include "uartdebug.h"


// Primitive I/O operations
char z1_singleread (char adr);
void z1_singlewrite (char adr, char data);
char z1_flagready(char flag);
void z1_setflag(char flag);


// Link and address operations
char z1_haslink(void);
char z1_haslink_wait(void);
void z1_force_relink(void);
char z1_arx_mute(char muting);


// Change the address used between ATX and ARX. 
// Needed only if EEPROM defaults have to be changed dynamically. Must be 
// present if not all EEPROMS have been programmed in matched pairs!
#ifdef Z1ALTERADDRESS
void z1_setprivateadr(void);
void z1_setinitialadr(void);
#endif // Z1ALTERADDRESS


// LED at ARX
#ifdef USELED
void z1_arxled(char mode);
char z1_rotate_led(void);
#endif // USELED


// ATX interrupts from nRF24Z1 to MCU
#ifdef Z1INTERRUPT
char z1_intstatus(void);
void z1_intinit(char interrupts);
void z1_intdeactivate(void);
#endif // Z1INTERRUPT

#endif
